%%Structure parameters

% 	INPUTS:  1) Ground Acceleration [mm/s/s]
%			 2) Damper Force at 1st Floor [N]
%
%	OUTPUTS:	1-2)   DISPLACEMENTS RELATIVE TO THE GROUND [mm]
%				3-4)  VELOCITIES RELATIVE TO THE GROUND [mm]
%				5-6) ABSOLUTE ACCELERATIONS [mm/s/s]
%
%
%
%
%    Written by: Xin Li, Tongji University, August 2013
%                with support from Sarah Hacker and 
%                Shirley J. Dyke, Purdue University 
%    
%
% References: Christenson paper for the structure model, 
%             Xiuyu Gao thesis for the MR damper model parameters. 
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%      EARTHQUAKE EXCITATION GAIN      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

GA_gain = 100;  %(for 1/10 scale earthquake) cm/s^2

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%      BUILDING DIMENSIONS/INPUTS      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Loading Structure Parameters ...')

flr 	 = [1 2];              % identify floors with control devices 
nms  	 = 2;				   % number of floors
nflr     = length(flr);		% number of floors with devices
mf  	 = 2.701;			% mass per floor [N/(mm/sec2)]
kf       = 279.171 ;	    % N/mm

% MULTI-STORY M-C-K SYSTEM
M    = mf*eye(nms);
temp = ones(1,nms-1);
K    = [diag([2*kf*temp kf])+diag([-kf*temp],-1)+diag([-kf*temp],1)];

% DAMPING MATRIX
[v,d] = eig(inv(M)*K);
wn    = sqrt(diag(d));
zeta  = 0.05;
C     = 2*zeta*mf*diag([wn]);
C     = v*C*v';

% STATE SPACE 
GAM  = [-ones(nms,1)];
P2 = zeros(nms,1); P2(1,1) = 1;

Aeval   = [zeros(nms) eye(nms);-inv(M)*K -inv(M)*C];
Beval=  [ zeros(2,2); GAM inv(M)*P2]; 
Ceval = [eye(2*nms);-inv(M)*K -inv(M)*C];
Deval = [[zeros(3*nms,1)] [zeros(2*nms,1); inv(M)*P2] ];

% CREATE VECTORS TO DEFINE CONNECTOR OUTPUTS 
Oc1	       = [1 3];
outsize = length(Ceval(:,1));
connsize  = length(Oc1); 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     MR Damper Parameters        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Loading Damper Parameters ...')

Umax   	= 3;	         	% 3 Volts produces max force levels
Umin     = 0;              % min command is 0 (semi-def positive)
 
alpha_a = 1.92;   %N/mm
alpha_b = 5.88;    %N/mm/V
c0_a = 0.65;       %N*sec/mm
c0_b = 1.04;       %N*sec/mm/V
k0 = 1.94;         %N/mm
gamma = 0.036;     %mm-2
beta = gamma;       %mm-2
A = 155.32;
x0 = 0;
n = 2;
eta = 60;         %s-1
k1 = 0.00175;     %N/mm
c1_a = 2.09;     %N*sec/mm
c1_b = 14.38;    %N*sec/mm/V

disp('Parameters Defined')